==> zio-aws-servicecatalog_2.13-5.17.116.1-sources.jar: zio/aws/servicecatalog/model/ListPortfoliosForProductResponse.scala <==
package zio.aws.servicecatalog.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.servicecatalog.model.primitives.PageToken
import scala.jdk.CollectionConverters._
final case class ListPortfoliosForProductResponse(
    portfolioDetails: Option[
      Iterable[zio.aws.servicecatalog.model.PortfolioDetail]
    ] = None,
    nextPageToken: Option[PageToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.servicecatalog.model.ListPortfoliosForProductResponse = {
    import ListPortfoliosForProductResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.servicecatalog.model.ListPortfoliosForProductResponse
      .builder()
      .optionallyWith(
        portfolioDetails.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.portfolioDetails)
      .optionallyWith(
        nextPageToken.map(value => PageToken.unwrap(value): java.lang.String)
      )(_.nextPageToken)
      .build()
  }
  def asReadOnly
      : zio.aws.servicecatalog.model.ListPortfoliosForProductResponse.ReadOnly =
    zio.aws.servicecatalog.model.ListPortfoliosForProductResponse
      .wrap(buildAwsValue())
}
object ListPortfoliosForProductResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.servicecatalog.model.ListPortfoliosForProductResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.servicecatalog.model.ListPortfoliosForProductResponse =
      zio.aws.servicecatalog.model.ListPortfoliosForProductResponse(
        portfolioDetails.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextPageToken.map(value => value)
      )
    def portfolioDetails
        : Option[List[zio.aws.servicecatalog.model.PortfolioDetail.ReadOnly]]
    def nextPageToken: Option[PageToken]
    def getPortfolioDetails: ZIO[Any, AwsError, List[
      zio.aws.servicecatalog.model.PortfolioDetail.ReadOnly
    ]] = AwsError.unwrapOptionField("portfolioDetails", portfolioDetails)
    def getNextPageToken: ZIO[Any, AwsError, PageToken] =
      AwsError.unwrapOptionField("nextPageToken", nextPageToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.servicecatalog.model.ListPortfoliosForProductResponse
  ) extends zio.aws.servicecatalog.model.ListPortfoliosForProductResponse.ReadOnly {
    override val portfolioDetails
        : Option[List[zio.aws.servicecatalog.model.PortfolioDetail.ReadOnly]] =
      scala
        .Option(impl.portfolioDetails())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.servicecatalog.model.PortfolioDetail.wrap(item)
          }.toList
        )
    override val nextPageToken: Option[PageToken] = scala
      .Option(impl.nextPageToken())
      .map(value => zio.aws.servicecatalog.model.primitives.PageToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.servicecatalog.model.ListPortfoliosForProductResponse
  ): zio.aws.servicecatalog.model.ListPortfoliosForProductResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-servicecatalog_2.13-6.20.103.2-sources.jar: zio/aws/servicecatalog/model/ListPortfoliosForProductResponse.scala <==
package zio.aws.servicecatalog.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.servicecatalog.model.primitives.PageToken
import scala.jdk.CollectionConverters._
final case class ListPortfoliosForProductResponse(
    portfolioDetails: Optional[
      Iterable[zio.aws.servicecatalog.model.PortfolioDetail]
    ] = Optional.Absent,
    nextPageToken: Optional[PageToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.servicecatalog.model.ListPortfoliosForProductResponse = {
    import ListPortfoliosForProductResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.servicecatalog.model.ListPortfoliosForProductResponse
      .builder()
      .optionallyWith(
        portfolioDetails.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.portfolioDetails)
      .optionallyWith(
        nextPageToken.map(value => PageToken.unwrap(value): java.lang.String)
      )(_.nextPageToken)
      .build()
  }
  def asReadOnly
      : zio.aws.servicecatalog.model.ListPortfoliosForProductResponse.ReadOnly =
    zio.aws.servicecatalog.model.ListPortfoliosForProductResponse
      .wrap(buildAwsValue())
}
object ListPortfoliosForProductResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.servicecatalog.model.ListPortfoliosForProductResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.servicecatalog.model.ListPortfoliosForProductResponse =
      zio.aws.servicecatalog.model.ListPortfoliosForProductResponse(
        portfolioDetails.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextPageToken.map(value => value)
      )
    def portfolioDetails
        : Optional[List[zio.aws.servicecatalog.model.PortfolioDetail.ReadOnly]]
    def nextPageToken: Optional[PageToken]
    def getPortfolioDetails: ZIO[Any, AwsError, List[
      zio.aws.servicecatalog.model.PortfolioDetail.ReadOnly
    ]] = AwsError.unwrapOptionField("portfolioDetails", portfolioDetails)
    def getNextPageToken: ZIO[Any, AwsError, PageToken] =
      AwsError.unwrapOptionField("nextPageToken", nextPageToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.servicecatalog.model.ListPortfoliosForProductResponse
  ) extends zio.aws.servicecatalog.model.ListPortfoliosForProductResponse.ReadOnly {
    override val portfolioDetails: Optional[
      List[zio.aws.servicecatalog.model.PortfolioDetail.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.portfolioDetails())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.servicecatalog.model.PortfolioDetail.wrap(item)
        }.toList
      )
    override val nextPageToken: Optional[PageToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextPageToken())
      .map(value => zio.aws.servicecatalog.model.primitives.PageToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.servicecatalog.model.ListPortfoliosForProductResponse
  ): zio.aws.servicecatalog.model.ListPortfoliosForProductResponse.ReadOnly =
    new Wrapper(impl)
}
